@@ -1,6 +1,6 @@
 =head1 NAME
 
-PDL::Graphics::TriD::Labels -- Text tools
+PDL::Graphics::TriD::Labels - Text tools
 
 =head1 SYNOPSIS
 
@@ -8,7 +8,6 @@ PDL::Graphics::TriD::Labels -- Text tools
 					  {Strings=>$strlist
 					   ,Font=>$font});
 
-
 =head1 WARNING
 
 This module is experimental and the interface will probably change.
@@ -27,13 +26,14 @@ conditions. For details, see the file COPYING in the PDL
 distribution. If this file is separated from the PDL distribution,
 the copyright notice should be included in the file.
 
-
 =cut
 package PDL::Graphics::TriD::Labels;
 
-use OpenGL qw(:all);
+use strict;
+use warnings;
+use OpenGL qw/ :glfunctions :glconstants /;
+use OpenGL::GLUT qw/ :all /;
 use PDL::Graphics::OpenGL::Perl::OpenGL;
-
 use PDL::Graphics::OpenGLQ;
 use base qw/PDL::Graphics::TriD::GObject/;
 
@@ -41,13 +41,13 @@ sub gdraw {
 	my($this,$points) = @_;
 	glDisable(&GL_LIGHTING);
 	glColor3d(1,1,1);
-	PDL::Graphics::OpenGLQ::gl_texts($points,$this->{Options}{Font},$this->{Options}{Strings});
+	PDL::Graphics::OpenGLQ::gl_texts($points,done_glutInit(),@{$this->{Options}}{qw(Font Strings)});
 	glEnable(&GL_LIGHTING);
 }
 
+$PDL::Graphics::TriD::GL::fontbase = $PDL::Graphics::TriD::GL::fontbase;
 sub get_valid_options {
   return {UseDefcols => 0, Font=>$PDL::Graphics::TriD::GL::fontbase, Strings => [] }
 }
 
-
 1;
